@@ -3,7 +3,7 @@ from typing import Any, Iterable
 
 ERROR_CODE = "DOC001"
 CHECK = "missing docstring"
-VERSION = "0.1.2"
+VERSION = "0.1.3"
 
 
 class DocstringChecker(ast.NodeVisitor):
@@ -12,7 +12,15 @@ class DocstringChecker(ast.NodeVisitor):
         self.errors: list[tuple[int, int, str]] = []
 
     def visit_FunctionDef(self, node: ast.FunctionDef) -> None:
-        # guard 1: if return type is Mock, don't check for docstring
+        # guard 1: if function is a pytest fixture, don't check for docstring
+        if any(
+            isinstance(decorator, ast.Attribute)
+            and decorator.attr == "fixture"
+            and isinstance(decorator.value, ast.Name)
+            and decorator.value.id == "pytest"
+            for decorator in node.decorator_list
+        ):
+            return
         if isinstance(node.returns, ast.Name) and node.returns.id.endswith("Mock"):
             return
 
